@@ -1,6 +1,6 @@
 /*@z49.c:PostScript Back End:PS_BackEnd@**************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.35)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.36)                       */
 /*  COPYRIGHT (C) 1991, 2007 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@it.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either Version 2, or (at your option)      */
+/*  the Free Software Foundation; either Version 3, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -895,9 +895,14 @@ static void PS_PrintBeforeFirstPage(FULL_LENGTH h, FULL_LENGTH v,
   p0("% p LoutSetTexture -");
   p0("/LoutSetTexture");
   p0("{");
-  p0("  LoutCurrentCCS");
-  p0("  3 -1 roll");
-  p0("  LoutSetCCSP");
+  if( UseTexture )
+  {
+    p0("  LoutCurrentCCS");
+    p0("  3 -1 roll");
+    p0("  LoutSetCCSP");
+  }
+  else
+    p0("  pop % textures not used");
   p0("} bind def");
   pnl;
 
